@@ -42,7 +42,7 @@ FAILEDOPERATION_APPIDISNULL = 'FailedOperation.AppIdIsNull'
 FAILEDOPERATION_APPIDNOTFOUND = 'FailedOperation.AppIdNotFound'
 
 # 应用不存在。
-FAILEDOPERATION_APPNOTEXISTED = 'FailedOperation.AppNotExisted'
+FAILEDOPERATION_APPNOTEXIST = 'FailedOperation.AppNotExist'
 
 # 同一组织下不能存在相同名称的子组织机构。
 FAILEDOPERATION_CHILDORGNODENAMEEXISTS = 'FailedOperation.ChildOrgNodeNameExists'
@@ -62,6 +62,9 @@ FAILEDOPERATION_CREATEUSERGROUPFAILURE = 'FailedOperation.CreateUserGroupFailure
 # 自定义机构节点对外ID已存在。
 FAILEDOPERATION_CUSTOMIZEDPARENTORGNODEIDEXISTED = 'FailedOperation.CustomizedParentOrgNodeIdExisted'
 
+# 默认导入机构不能被删除。
+FAILEDOPERATION_DEFAULTORGNODECANNOTBEDELETED = 'FailedOperation.DefaultOrgNodeCanNotBeDeleted'
+
 # 删除机构节点失败。
 FAILEDOPERATION_DELETEORGNODEFAILURE = 'FailedOperation.DeleteOrgNodeFailure'
 
@@ -162,7 +165,7 @@ FAILEDOPERATION_UPDATEWECOMUSERORGNOTINSAMECROP = 'FailedOperation.UpdateWeComUs
 FAILEDOPERATION_USERALREADYEXISTEDINUSERGROUP = 'FailedOperation.UserAlreadyExistedInUserGroup'
 
 # 获取用户被授权访问的应用列表失败。
-FAILEDOPERATION_USERAUTHLISTFAILED = 'FailedOperation.UserAuthListFailed'
+FAILEDOPERATION_USERAUTHLISTERROR = 'FailedOperation.UserAuthListError'
 
 # 用户邮箱已存在。
 FAILEDOPERATION_USEREMAILEXISTED = 'FailedOperation.UserEmailExisted'
