@@ -98,6 +98,9 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 应用号不存在。
 RESOURCENOTFOUND_APPLICATION = 'ResourceNotFound.Application'
 
+# 机构不存在。
+RESOURCENOTFOUND_ORGANIZATION = 'ResourceNotFound.Organization'
+
 # 模板不存在。
 RESOURCENOTFOUND_TEMPLATE = 'ResourceNotFound.Template'
 
