@@ -17,12 +17,18 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 操作未授权。
+AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
 # 请检查是否有权限。
 FAILEDOPERATION_AUTHERROR = 'FailedOperation.AuthError'
 
+# CAM鉴权出现错误。
+FAILEDOPERATION_CAMAUTHORIZEDFAIL = 'FailedOperation.CAMAuthorizedFail'
+
 # 取消订单失败。
 FAILEDOPERATION_CANCELORDERFAILED = 'FailedOperation.CancelOrderFailed'
 
